@@ -1,10 +1,11 @@
+import asyncio
 import os
 import importlib.util
 import importlib.machinery
-import time
 import sys
 import types
 import typing
+import traceback
 
 from mitmproxy import addonmanager
 from mitmproxy import exceptions
@@ -12,6 +13,7 @@ from mitmproxy import flow
 from mitmproxy import command
 from mitmproxy import eventsequence
 from mitmproxy import ctx
+import mitmproxy.types as mtypes
 
 
 def load_script(path: str) -> types.ModuleType:
@@ -23,6 +25,7 @@ def load_script(path: str) -> types.ModuleType:
     sys.modules.pop(fullname, None)
     oldpath = sys.path
     sys.path.insert(0, os.path.dirname(path))
+    m = None
     try:
         loader = importlib.machinery.SourceFileLoader(fullname, path)
         spec = importlib.util.spec_from_loader(fullname, loader=loader)
@@ -30,18 +33,41 @@ def load_script(path: str) -> types.ModuleType:
         loader.exec_module(m)
         if not getattr(m, "name", None):
             m.name = path  # type: ignore
-        return m
+    except Exception as e:
+        script_error_handler(path, e, msg=str(e))
     finally:
         sys.path[:] = oldpath
+        return m
+
+
+def script_error_handler(path, exc, msg="", tb=False):
+    """
+        Handles all the user's script errors with
+        an optional traceback
+    """
+    exception = type(exc).__name__
+    if msg:
+        exception = msg
+    lineno = ""
+    if hasattr(exc, "lineno"):
+        lineno = str(exc.lineno)
+    log_msg = "in script {}:{} {}".format(path, lineno, exception)
+    if tb:
+        etype, value, tback = sys.exc_info()
+        tback = addonmanager.cut_traceback(tback, "invoke_addon")
+        log_msg = log_msg + "\n" + "".join(traceback.format_exception(etype, value, tback))
+    ctx.log.error(log_msg)
+
+
+ReloadInterval = 1
 
 
 class Script:
     """
         An addon that manages a single script.
     """
-    ReloadInterval = 2
 
-    def __init__(self, path):
+    def __init__(self, path: str, reload: bool) -> None:
         self.name = "scriptmanager:" + path
         self.path = path
         self.fullpath = os.path.expanduser(
@@ -49,45 +75,57 @@ class Script:
         )
         self.ns = None
 
-        self.last_load = 0
-        self.last_mtime = 0
         if not os.path.isfile(self.fullpath):
-            raise exceptions.OptionsError('No such script: "%s"' % self.fullpath)
+            raise exceptions.OptionsError('No such script')
+
+        self.reloadtask = None
+        if reload:
+            self.reloadtask = asyncio.ensure_future(self.watcher())
+        else:
+            self.loadscript()
+
+    def done(self):
+        if self.reloadtask:
+            self.reloadtask.cancel()
 
     @property
     def addons(self):
         return [self.ns] if self.ns else []
 
-    def tick(self):
-        if time.time() - self.last_load > self.ReloadInterval:
+    def loadscript(self):
+        ctx.log.info("Loading script %s" % self.path)
+        if self.ns:
+            ctx.master.addons.remove(self.ns)
+        self.ns = None
+        with addonmanager.safecall():
+            ns = load_script(self.fullpath)
+            ctx.master.addons.register(ns)
+            self.ns = ns
+        if self.ns:
+            # We're already running, so we have to explicitly register and
+            # configure the addon
+            ctx.master.addons.invoke_addon(self.ns, "running")
+            ctx.master.addons.invoke_addon(
+                self.ns,
+                "configure",
+                ctx.options.keys()
+            )
+
+    async def watcher(self):
+        last_mtime = 0
+        while True:
             try:
                 mtime = os.stat(self.fullpath).st_mtime
             except FileNotFoundError:
+                ctx.log.info("Removing script %s" % self.path)
                 scripts = list(ctx.options.scripts)
                 scripts.remove(self.path)
                 ctx.options.update(scripts=scripts)
                 return
-
-            if mtime > self.last_mtime:
-                ctx.log.info("Loading script: %s" % self.path)
-                if self.ns:
-                    ctx.master.addons.remove(self.ns)
-                self.ns = None
-                with addonmanager.safecall():
-                    ns = load_script(self.fullpath)
-                    ctx.master.addons.register(ns)
-                    self.ns = ns
-                if self.ns:
-                    # We're already running, so we have to explicitly register and
-                    # configure the addon
-                    ctx.master.addons.invoke_addon(self.ns, "running")
-                    ctx.master.addons.invoke_addon(
-                        self.ns,
-                        "configure",
-                        ctx.options.keys()
-                    )
-                self.last_load = time.time()
-                self.last_mtime = mtime
+            if mtime > last_mtime:
+                self.loadscript()
+                last_mtime = mtime
+            await asyncio.sleep(ReloadInterval)
 
 
 class ScriptLoader:
@@ -98,38 +136,47 @@ class ScriptLoader:
         self.is_running = False
         self.addons = []
 
+    def load(self, loader):
+        loader.add_option(
+            "scripts", typing.Sequence[str], [],
+            "Execute a script."
+        )
+
     def running(self):
         self.is_running = True
 
     @command.command("script.run")
-    def script_run(self, flows: typing.Sequence[flow.Flow], path: str) -> None:
+    def script_run(self, flows: typing.Sequence[flow.Flow], path: mtypes.Path) -> None:
         """
-            Run a script on the specified flows. The script is loaded with
-            default options, and all lifecycle events for each flow are
-            simulated.
+            Run a script on the specified flows. The script is configured with
+            the current options and all lifecycle events for each flow are
+            simulated. Note that the load event is not invoked.
         """
-        try:
-            s = Script(path)
-            l = addonmanager.Loader(ctx.master)
-            ctx.master.addons.invoke_addon(s, "load", l)
-            ctx.master.addons.invoke_addon(s, "configure", ctx.options.keys())
-            # Script is loaded on the first tick
-            ctx.master.addons.invoke_addon(s, "tick")
-            for f in flows:
-                for evt, arg in eventsequence.iterate(f):
-                    ctx.master.addons.invoke_addon(s, evt, arg)
-        except exceptions.OptionsError as e:
-            raise exceptions.CommandError("Error running script: %s" % e) from e
+        if not os.path.isfile(path):
+            ctx.log.error('No such script: %s' % path)
+            return
+        mod = load_script(path)
+        if mod:
+            with addonmanager.safecall():
+                ctx.master.addons.invoke_addon(mod, "running")
+                ctx.master.addons.invoke_addon(
+                    mod,
+                    "configure",
+                    ctx.options.keys()
+                )
+                for f in flows:
+                    for evt, arg in eventsequence.iterate(f):
+                        ctx.master.addons.invoke_addon(mod, evt, arg)
 
     def configure(self, updated):
         if "scripts" in updated:
             for s in ctx.options.scripts:
                 if ctx.options.scripts.count(s) > 1:
-                    raise exceptions.OptionsError("Duplicate script: %s" % s)
+                    raise exceptions.OptionsError("Duplicate script")
 
             for a in self.addons[:]:
                 if a.path not in ctx.options.scripts:
-                    ctx.log.info("Un-loading script: %s" % a.name)
+                    ctx.log.info("Un-loading script: %s" % a.path)
                     ctx.master.addons.remove(a)
                     self.addons.remove(a)
 
@@ -149,7 +196,7 @@ class ScriptLoader:
                 if s in current:
                     ordered.append(current[s])
                 else:
-                    sc = Script(s)
+                    sc = Script(s, True)
                     ordered.append(sc)
                     newscripts.append(sc)
 
